This function installs a specified AAGI Quarto extension into the current working directory or updates an existing installation to the version included in the package. The extension will be installed to the '_extensions' folder in the current directory.
Arguments
- ext_name
String indicating which extension to install. Must be one of "aagi-report", "aagi-short-report", "aagi-presentation", or "all" to install/update all bundled extensions.
- force
Logical indicating whether to force installation even if the extension already exists. Default is FALSE, which will prompt the user when an existing extension is found.